==============
pytest-pyright
==============

.. image:: https://img.shields.io/pypi/v/pytest-pyright.svg
    :target: https://pypi.org/project/pytest-pyright
    :alt: PyPI version

.. image:: https://img.shields.io/pypi/pyversions/pytest-pyright.svg
    :target: https://pypi.org/project/pytest-pyright
    :alt: Python versions

.. image:: https://readthedocs.org/projects/pytest-pyright/badge/?version=latest
    :target: https://pytest-pyright.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

⚠️ This project was created for internal use within another project of mine, support will be minimal.

Pytest plugin for type checking code with Pyright.

----

This `pytest`_ plugin was generated with `Cookiecutter`_ along with `@hackebrot`_'s `cookiecutter-pytest-plugin`_ template.


Why Should You Use it?
----------------------

pytest-pyright was created to ensure that complex types are correctly constrained, i.e will raise an error if used incorrectly.

if your project makes use of any complex types you should find some value out pytest-pyright.


Installation
------------

You can install "pytest-pyright" via `pip`_ from `PyPI`_::

    $ pip install pytest-pyright


Usage
-----

See the `documentation <https://pytest-pyright.readthedocs.io/en/latest/>`_

Contributing
------------
Contributions are very welcome. Tests can be run with `tox`_, please ensure
the coverage at least stays the same before you submit a pull request.

License
-------

Distributed under the terms of the `MIT`_ license, "pytest-pyright" is free and open source software


Issues
------

If you encounter any problems, please `file an issue`_ along with a detailed description.

.. _`Cookiecutter`: https://github.com/audreyr/cookiecutter
.. _`@hackebrot`: https://github.com/hackebrot
.. _`MIT`: http://opensource.org/licenses/MIT
.. _`BSD-3`: http://opensource.org/licenses/BSD-3-Clause
.. _`GNU GPL v3.0`: http://www.gnu.org/licenses/gpl-3.0.txt
.. _`Apache Software License 2.0`: http://www.apache.org/licenses/LICENSE-2.0
.. _`cookiecutter-pytest-plugin`: https://github.com/pytest-dev/cookiecutter-pytest-plugin
.. _`file an issue`: https://github.com/RobertCraigie/pytest-pyright/issues
.. _`pytest`: https://github.com/pytest-dev/pytest
.. _`tox`: https://tox.readthedocs.io/en/latest/
.. _`pip`: https://pypi.org/project/pip/
.. _`PyPI`: https://pypi.org/project/pytest-pyright/
